@@ -197,6 +197,7 @@ enum REGISTERCONNECTION_RETURN_VALUES {
         OER_REGISTERCONNECTION_ERR_WRITE,
         OER_REGISTERCONNECTION_ERR_HANDLESERVERDATA,
         OER_REGISTERCONNECTION_ALREADY_REGISTERED,
+        OER_REGISTERCONNECTION_TIMEOUT,
         OER_REGISTERCONNECTION_ERROR,
         OER_REGISTERCONNECTION_EVERYTHING_OK
 };
@@ -243,6 +244,7 @@ enum OER_TIMED_PRIORITIES {
         OER_TIMED_PRIORITY_CTCP,
         OER_TIMED_PRIORITY_NOTICE,
         OER_TIMED_PRIORITY_PRIVMSG,
+        OER_TIMED_PRIORITY_ADVERT,
         OER_TIMED_PRIORITY_NORMAL,
         OER_TIMED_PRIORITY_CHANNEL_HANDLING,
         OER_TIMED_PRIORITY_CHANNEL_PROTECTION,
@@ -259,7 +261,7 @@ enum OER_FLAGS_TYPE {
 #define OER_FLAGS_GLOBAL "dfglmnopqs"
 #define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
-#define OER_FLAGS_USER "!adfmovrx"
+#define OER_FLAGS_USER "!adfmovrsx"
 
 #define numofparams(x) (wordcount(x) - 1)
 
@@ -312,6 +314,7 @@ enum OER_FLAGS_TYPE {
 #define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
+#define OER_REGISTERCONNECTION_TIMEOUT 600
 #define OER_BANVARS_AUTO_REJOIN 30
 #define OER_BANVARS_PART_REJOIN 600
 #define OER_BANVARS_PUBLIC_FLOOD 300
@@ -349,6 +352,7 @@ enum OER_FLAGS_TYPE {
 #define HOSTLEN 63
 #define USERLEN 16
 #define NICKLEN 20
+#define IDENTLEN NICKLEN
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
 #define OER_MAX_LIST_LINES 5
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
@@ -360,7 +364,7 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-33, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-34, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -548,6 +552,7 @@ struct server {
 	time_t linkup;
 	char password[TINYSTRINGLEN + 1];
 	time_t lastping;
+	time_t registerconnection_start;
 	struct server *prev;
 	struct server *next;
 };
@@ -608,11 +613,12 @@ struct state {
 	char preferredserver[HOSTLEN + 1];
 	char realname[STRINGLEN + 1];
 	char flags[FLAGLEN + 1];
-	char ident[STRINGLEN + 1];
-	char adminsfrom[STRINGLEN + 1];
-	char usersfrom[STRINGLEN + 1];
+	char ident[IDENTLEN + 1];
+	char adminsfrom[IDENTLEN + 1];
+	char usersfrom[IDENTLEN + 1];
 	char prefix[TINYSTRINGLEN + 1];
 	char state[STRINGLEN + 1];
+	char proxysetup[STRINGLEN + 1];
 	int customuser;
 	int vhost;
 	int use_altnick;
@@ -630,6 +636,7 @@ struct state {
 	time_t admints;
 	time_t last_linenoise;
 	time_t last_gn;
+	time_t last_ts_check;
 	struct qauth qauth;
 	struct authed *autheds;
 	struct botuser *admins;
