@@ -62,8 +62,8 @@ int main(int argc, char *argv[])
         char *locptr;
 #endif
 	char config[TINYSTRINGLEN + 1];
-        char adminsfrom[STRINGLEN + 1];
-        char usersfrom[STRINGLEN + 1];
+        char adminsfrom[IDENTLEN + 1];
+        char usersfrom[IDENTLEN + 1];
         char state[STRINGLEN + 1];
 	int retval;
 	int c;
@@ -93,7 +93,7 @@ int main(int argc, char *argv[])
         while((c = getopt(argc, argv, "a:cd:f:hsu:t:v")) > 0) {
 		switch(c) {
 		case 'a':
-			strncpy(adminsfrom, optarg, STRINGLEN);
+			strncpy(adminsfrom, optarg, IDENTLEN);
 			oer_debug(OER_DEBUG_INFO, "main->I will get my admins with ident %s\n", adminsfrom);
 			do_adminsfrom = 1;
 			break;
@@ -113,7 +113,7 @@ int main(int argc, char *argv[])
 			do_signals = 0;
 			break;
 		case 'u':
-			strncpy(usersfrom, optarg, STRINGLEN);
+			strncpy(usersfrom, optarg, IDENTLEN);
 			oer_debug(OER_DEBUG_INFO, "main->I will get my users with ident %s\n", usersfrom);
 			do_usersfrom = 1;
 			break;
@@ -130,7 +130,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	if(do_help) {
-		oer_debug(OER_DEBUG_INFO, "usage: %s [-c] [-d <level>] [-f <config>] [-h] [-s] [-u <ident>] [-t <state>] [-v]\n", argv[0]);
+		oer_debug(OER_DEBUG_INFO, "usage: %s [-a <ident>] [-c] [-d <level>] [-f <config>] [-h] [-s] [-u <ident>] [-t <state>] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	}
 	oer_debug(OER_DEBUG_INFO, "%s\n\n", OER_COPYRIGHT1);
