@@ -5,10 +5,10 @@
 # Server version	3.23.32
 
 #
-# Table structure for table 'admins'
+# Table structure for table 'oer_admins'
 #
 
-CREATE TABLE admins (
+CREATE TABLE oer_admins (
   handle VARCHAR(32) NOT NULL DEFAULT '',
   flags VARCHAR(32) DEFAULT '',
   ident VARCHAR(64) NOT NULL DEFAULT '',
@@ -16,10 +16,10 @@ CREATE TABLE admins (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'adverts'
+# Table structure for table 'oer_adverts'
 #
 
-CREATE TABLE adverts (
+CREATE TABLE oer_adverts (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   type VARCHAR(32) NOT NULL DEFAULT '',
   message TEXT NOT NULL,
@@ -27,10 +27,10 @@ CREATE TABLE adverts (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'bantype'
+# Table structure for table 'oer_bantype'
 #
 
-CREATE TABLE bantype (
+CREATE TABLE oer_bantype (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   type TINYINT UNSIGNED NOT NULL DEFAULT '1',
   ident VARCHAR(64) NOT NULL DEFAULT '',
@@ -38,10 +38,10 @@ CREATE TABLE bantype (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'banvars'
+# Table structure for table 'oer_banvars'
 #
 
-CREATE TABLE banvars (
+CREATE TABLE oer_banvars (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   b_auto_rejoin SMALLINT UNSIGNED NOT NULL DEFAULT '30',
   b_part_rejoin SMALLINT UNSIGNED NOT NULL DEFAULT '600',
@@ -55,10 +55,10 @@ CREATE TABLE banvars (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'channels'
+# Table structure for table 'oer_channels'
 #
 
-CREATE TABLE channels (
+CREATE TABLE oer_channels (
   name VARCHAR(50) NOT NULL DEFAULT '',
   chanmodes VARCHAR(12) DEFAULT '',
   chankey VARCHAR(32) DEFAULT '',
@@ -69,10 +69,10 @@ CREATE TABLE channels (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'conf'
+# Table structure for table 'oer_conf'
 #
 
-CREATE TABLE conf (
+CREATE TABLE oer_conf (
   nick VARCHAR(20) NOT NULL DEFAULT '',
   altnick VARCHAR(20) NOT NULL DEFAULT '',
   user VARCHAR(16) DEFAULT '',
@@ -84,15 +84,16 @@ CREATE TABLE conf (
   qhost VARCHAR(80) DEFAULT '',
   qname VARCHAR(32) DEFAULT '',
   qpassword VARCHAR(32) DEFAULT '',
+  proxysetup VARCHAR(128) DEFAULT '',
   ident VARCHAR(32) NOT NULL DEFAULT '',
   PRIMARY KEY (ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'floodvars'
+# Table structure for table 'oer_floodvars'
 #
 
-CREATE TABLE floodvars (
+CREATE TABLE oer_floodvars (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   f_expire SMALLINT UNSIGNED NOT NULL DEFAULT '1800',
   f_limit SMALLINT UNSIGNED NOT NULL DEFAULT '3',
@@ -106,10 +107,10 @@ CREATE TABLE floodvars (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'hostmasks'
+# Table structure for table 'oer_hostmasks'
 #
 
-CREATE TABLE hostmasks (
+CREATE TABLE oer_hostmasks (
   hostmask VARCHAR(80) NOT NULL DEFAULT '',
   channel VARCHAR(50) NOT NULL DEFAULT '',
   type TINYINT UNSIGNED NOT NULL DEFAULT '0',
@@ -119,32 +120,33 @@ CREATE TABLE hostmasks (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'kickreasons'
+# Table structure for table 'oer_kickreasons'
 #
 
-CREATE TABLE kickreasons (
+CREATE TABLE oer_kickreasons (
   reason VARCHAR(255) NOT NULL DEFAULT '',
   ident VARCHAR(64) NOT NULL DEFAULT ''
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'last'
+# Table structure for table 'oer_last'
 #
 
-CREATE TABLE last (
+CREATE TABLE oer_last (
   channel VARCHAR(50) NOT NULL,
   nick VARCHAR(20) NOT NULL,
   twhen INT UNSIGNED NOT NULL,
   hostmask VARCHAR(80) NOT NULL,
+  ident VARCHAR(64) NOT NULL,
   message TEXT NOT NULL,
-  INDEX (channel,nick)
+  INDEX (channel,nick,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'nickbks'
+# Table structure for table 'oer_nickbks'
 #
 
-CREATE TABLE nickbks (
+CREATE TABLE oer_nickbks (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   pattern VARCHAR(32) NOT NULL DEFAULT '',
   reason VARCHAR(64) DEFAULT '',
@@ -155,20 +157,20 @@ CREATE TABLE nickbks (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'output'
+# Table structure for table 'oer_output'
 #
 
-CREATE TABLE output (
+CREATE TABLE oer_output (
   twhen INT UNSIGNED NOT NULL DEFAULT '0',
   ident VARCHAR(64) NOT NULL DEFAULT '',
   message TEXT NOT NULL
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'passwords'
+# Table structure for table 'oer_passwords'
 #
 
-CREATE TABLE passwords (
+CREATE TABLE oer_passwords (
   handle VARCHAR(32) NOT NULL DEFAULT '',
   channel VARCHAR(50) NOT NULL DEFAULT '',
   type TINYINT unsigned NOT NULL DEFAULT '0',
@@ -178,10 +180,10 @@ CREATE TABLE passwords (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'permbans'
+# Table structure for table 'oer_permbans'
 #
 
-CREATE TABLE permbans (
+CREATE TABLE oer_permbans (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   mask VARCHAR(64) NOT NULL DEFAULT '',
   reason VARCHAR(64) DEFAULT '',
@@ -192,32 +194,33 @@ CREATE TABLE permbans (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'raw'
+# Table structure for table 'oer_raw'
 #
 
-CREATE TABLE raw (
+CREATE TABLE oer_raw (
   twhen INT UNSIGNED NOT NULL DEFAULT '0',
   ident VARCHAR(64) NOT NULL DEFAULT '',
   message TEXT NOT NULL
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'seen'
+# Table structure for table 'oer_seen'
 #
 
-CREATE TABLE seen (
+CREATE TABLE oer_seen (
   channel VARCHAR(50) NOT NULL,
   nick VARCHAR(20) NOT NULL,
   twhen INT UNSIGNED NOT NULL,
   hostmask VARCHAR(80) NOT NULL,
-  INDEX (channel,nick)
+  ident VARCHAR(64) NOT NULL,
+  INDEX (channel,nick,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'servers'
+# Table structure for table 'oer_servers'
 #
 
-CREATE TABLE servers (
+CREATE TABLE oer_servers (
   hostname VARCHAR(63) NOT NULL DEFAULT '',
   port SMALLINT UNSIGNED NOT NULL DEFAULT '6667',
   servermodes TINYINT UNSIGNED NOT NULL DEFAULT '4',
@@ -232,20 +235,20 @@ CREATE TABLE servers (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'services'
+# Table structure for table 'oer_services'
 #
 
-CREATE TABLE services (
+CREATE TABLE oer_services (
   host VARCHAR(63) NOT NULL DEFAULT '',
   ident VARCHAR(64) NOT NULL DEFAULT '',
   PRIMARY KEY (host,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'timestamps'
+# Table structure for table 'oer_timestamps'
 #
 
-CREATE TABLE timestamps (
+CREATE TABLE oer_timestamps (
   ttype VARCHAR(32) NOT NULL DEFAULT '',
   twhen INT UNSIGNED NOT NULL DEFAULT '0',
   tchannel VARCHAR(50) NOT NULL DEFAULT '',
@@ -254,10 +257,10 @@ CREATE TABLE timestamps (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'topics'
+# Table structure for table 'oer_topics'
 #
 
-CREATE TABLE topics (
+CREATE TABLE oer_topics (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   pos TINYINT UNSIGNED NOT NULL DEFAULT '0',
   twhen INT UNSIGNED NOT NULL DEFAULT '0',
@@ -267,20 +270,20 @@ CREATE TABLE topics (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'trusted'
+# Table structure for table 'oer_trusted'
 #
 
-CREATE TABLE trusted (
+CREATE TABLE oer_trusted (
   host VARCHAR(63) NOT NULL DEFAULT '',
   ident VARCHAR(64) NOT NULL DEFAULT '',
   PRIMARY KEY (host,ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'users'
+# Table structure for table 'oer_users'
 #
 
-CREATE TABLE users (
+CREATE TABLE oer_users (
   handle VARCHAR(32) NOT NULL DEFAULT '',
   channel VARCHAR(50) NOT NULL DEFAULT '',
   flags VARCHAR(32) DEFAULT '',
@@ -289,10 +292,10 @@ CREATE TABLE users (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 #
-# Table structure for table 'wordbks'
+# Table structure for table 'oer_wordbks'
 #
 
-CREATE TABLE wordbks (
+CREATE TABLE oer_wordbks (
   channel VARCHAR(50) NOT NULL DEFAULT '',
   pattern VARCHAR(32) NOT NULL DEFAULT '',
   reason VARCHAR(64) DEFAULT '',
